# LibPython

Este projeto suport a versão  do _python_ especificaente a versão 3.8.8

Tópicos abordaos:

* virtualenv
* flake8


#### Instalação das dependências no _Linux_
```console
 python3 -m venv .venv
 source .venv/bin/activate
 pip install -r requiriments-dev.txt
 ```

#### Instalação das dependências no _Windows_
```console
 python -m venv .venv
 [CMD] cd .venv/bin/activate.bat
 [POWERSHEL] cd .venv/bin/activate.ps1
 pip install -r requiriments-dev.txt
 ```
[![Build Status](https://travis-ci.com/JeanTheodoro/LibPython.svg?branch=main)](https://travis-ci.com/JeanTheodoro/LibPython)
[![Updates](https://pyup.io/repos/github/JeanTheodoro/LibPython/shield.svg)](https://pyup.io/repos/github/JeanTheodoro/LibPython/)
[![Python 3](https://pyup.io/repos/github/JeanTheodoro/LibPython/python-3-shield.svg)](https://pyup.io/repos/github/JeanTheodoro/LibPython/)